==> cegui-mk2_0.8.4+dfsg.orig.tar.bz2: cegui-0.8.4/samples/common/include/Sample.h <==
/***********************************************************************
created:    29/5/2012
author:     Lukas E Meindl
*************************************************************************/
/***************************************************************************
*   Copyright (C) 2004 - 2012 Paul D Turner & The CEGUI Development Team
*
*   Permission is hereby granted, free of charge, to any person obtaining
*   a copy of this software and associated documentation files (the
*   "Software"), to deal in the Software without restriction, including
*   without limitation the rights to use, copy, modify, merge, publish,
*   distribute, sublicense, and/or sell copies of the Software, and to
*   permit persons to whom the Software is furnished to do so, subject to
*   the following conditions:
*
*   The above copyright notice and this permission notice shall be
*   included in all copies or substantial portions of the Software.
*
*   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
*   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
*   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
*   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
*   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
*   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
*   OTHER DEALINGS IN THE SOFTWARE.
***************************************************************************/
#ifndef _Sample_h_
#define _Sample_h_

#include "CEGUI/String.h"

// This header serves as a base for all samples and is needed inside the
// SamplesFramework as interface for Samples that will be loaded.
#include "CEGUI/ForwardRefs.h"

class Sample
{
public:
    virtual bool initialise(CEGUI::GUIContext* guiContext) = 0;
    virtual void deinitialise() = 0;

    virtual void onEnteringSample() {}
    virtual void update(float timeSinceLastUpdate) {}

    const CEGUI::String& getUsedFilesString() {return d_usedFiles;}

protected:
    CEGUI::String d_usedFiles;
};

#endif

==> cegui-mk2_0.8.7.orig.tar.bz2: cegui-0.8.7/samples/common/include/Sample.h <==
/***********************************************************************
created:    29/5/2012
author:     Lukas E Meindl
*************************************************************************/
/***************************************************************************
*   Copyright (C) 2004 - 2012 Paul D Turner & The CEGUI Development Team
*
*   Permission is hereby granted, free of charge, to any person obtaining
*   a copy of this software and associated documentation files (the
*   "Software"), to deal in the Software without restriction, including
*   without limitation the rights to use, copy, modify, merge, publish,
*   distribute, sublicense, and/or sell copies of the Software, and to
*   permit persons to whom the Software is furnished to do so, subject to
*   the following conditions:
*
*   The above copyright notice and this permission notice shall be
*   included in all copies or substantial portions of the Software.
*
*   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
*   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
*   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
*   IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
*   OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
*   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
*   OTHER DEALINGS IN THE SOFTWARE.
***************************************************************************/
#ifndef _Sample_h_
#define _Sample_h_

#include "CEGUI/String.h"

// This header serves as a base for all samples and is needed inside the
// SamplesFramework as interface for Samples that will be loaded.
#include "CEGUI/ForwardRefs.h"

class Sample
{
public:
    virtual bool initialise(CEGUI::GUIContext* guiContext) = 0;
    virtual void deinitialise() = 0;

    virtual void onEnteringSample() {}
    virtual void update(float /*timeSinceLastUpdate*/) {}

    const CEGUI::String& getUsedFilesString() {return d_usedFiles;}

protected:
    CEGUI::String d_usedFiles;
};

#endif
